==> touhoulittlemaid-fabric-1.21.1-0.0.7-neo1.3.6-sources.jar: com/github/tartaricacid/touhoulittlemaid/init/InitBlocks.java <==
package com.github.tartaricacid.touhoulittlemaid.init;

import com.github.tartaricacid.touhoulittlemaid.TouhouLittleMaid;
import com.github.tartaricacid.touhoulittlemaid.block.*;
import com.github.tartaricacid.touhoulittlemaid.tileentity.*;
import net.minecraft.class_2248;
import net.minecraft.class_2378;
import net.minecraft.class_2591;
import net.minecraft.class_2960;
import net.minecraft.class_7923;

public final class InitBlocks {
    public static void init() {

    }

    public static class_2248 MAID_BED = registerBlock("maid_bed", new BlockMaidBed());
    public static class_2248 ALTAR = registerBlock("altar", new BlockAltar());
    public static class_2248 STATUE = registerBlock("statue", new BlockStatue());
    public static class_2248 GARAGE_KIT = registerBlock("garage_kit", new BlockGarageKit());
    public static class_2248 MAID_BEACON = registerBlock("maid_beacon", new BlockMaidBeacon());
    public static class_2248 MODEL_SWITCHER = registerBlock("model_switcher", new BlockModelSwitcher());
    public static class_2248 PICNIC_MAT = registerBlock("picnic_mat", new BlockPicnicMat());
    public static class_2248 GOMOKU = registerBlock("gomoku", new BlockGomoku());
    public static class_2248 CCHESS = registerBlock("cchess", new BlockCChess());
    public static class_2248 WCHESS = registerBlock("wchess", new BlockWChess());
    public static class_2248 KEYBOARD = registerBlock("keyboard", new BlockKeyboard());
    public static class_2248 BOOKSHELF = registerBlock("bookshelf", new BlockBookshelf());
    public static class_2248 COMPUTER = registerBlock("computer", new BlockComputer());
    public static class_2248 SHRINE = registerBlock("shrine", new BlockShrine());
    public static class_2248 SCARECROW = registerBlock("scarecrow", new BlockScarecrow());

    public static class_2591<TileEntityAltar> ALTAR_TE = registerBlockEntityType("altar", TileEntityAltar.TYPE);
    public static class_2591<TileEntityStatue> STATUE_TE = registerBlockEntityType("statue", TileEntityStatue.TYPE);
    public static class_2591<TileEntityGarageKit> GARAGE_KIT_TE = registerBlockEntityType("garage_kit", TileEntityGarageKit.TYPE);
    public static class_2591<TileEntityMaidBeacon> MAID_BEACON_TE = registerBlockEntityType("maid_beacon", TileEntityMaidBeacon.TYPE);
    public static class_2591<TileEntityModelSwitcher> MODEL_SWITCHER_TE = registerBlockEntityType("model_switcher", TileEntityModelSwitcher.TYPE);
    public static class_2591<TileEntityGomoku> GOMOKU_TE = registerBlockEntityType("gomoku", TileEntityGomoku.TYPE);
    public static class_2591<TileEntityCChess> CCHESS_TE = registerBlockEntityType("cchess", TileEntityCChess.TYPE);
    public static class_2591<TileEntityWChess> WCHESS_TE = registerBlockEntityType("wchess", TileEntityWChess.TYPE);
    public static class_2591<TileEntityKeyboard> KEYBOARD_TE = registerBlockEntityType("keyboard", TileEntityKeyboard.TYPE);
    public static class_2591<TileEntityBookshelf> BOOKSHELF_TE = registerBlockEntityType("bookshelf", TileEntityBookshelf.TYPE);
    public static class_2591<TileEntityComputer> COMPUTER_TE = registerBlockEntityType("computer", TileEntityComputer.TYPE);
    public static class_2591<TileEntityShrine> SHRINE_TE = registerBlockEntityType("shrine", TileEntityShrine.TYPE);
    public static class_2591<TileEntityPicnicMat> PICNIC_MAT_TE = registerBlockEntityType("picnic_mat", TileEntityPicnicMat.TYPE);

    private static class_2248 registerBlock(String id, class_2248 block) {
        return class_2378.method_10230(class_7923.field_41175, class_2960.method_60655(TouhouLittleMaid.MOD_ID, id), block);
    }

    private static <T extends class_2591<?>> T registerBlockEntityType(String id, T block) {
        return class_2378.method_10230(class_7923.field_41181, class_2960.method_60655(TouhouLittleMaid.MOD_ID, id), block);
    }
}

==> touhoulittlemaid-fabric-1.21.1-0.1.7.2-neo1.3.8-sources.jar: com/github/tartaricacid/touhoulittlemaid/init/InitBlocks.java <==
package com.github.tartaricacid.touhoulittlemaid.init;

import com.github.tartaricacid.touhoulittlemaid.TouhouLittleMaid;
import com.github.tartaricacid.touhoulittlemaid.block.*;
import com.github.tartaricacid.touhoulittlemaid.tileentity.*;
import net.minecraft.class_2248;
import net.minecraft.class_2378;
import net.minecraft.class_2591;
import net.minecraft.class_2960;
import net.minecraft.class_7923;

public final class InitBlocks {
    public static void init() {

    }

    public static class_2248 MAID_BED = registerBlock("maid_bed", new BlockMaidBed());
    public static class_2248 ALTAR = registerBlock("altar", new BlockAltar());
    public static class_2248 STATUE = registerBlock("statue", new BlockStatue());
    public static class_2248 GARAGE_KIT = registerBlock("garage_kit", new BlockGarageKit());
    public static class_2248 MAID_BEACON = registerBlock("maid_beacon", new BlockMaidBeacon());
    public static class_2248 MODEL_SWITCHER = registerBlock("model_switcher", new BlockModelSwitcher());
    public static class_2248 PICNIC_MAT = registerBlock("picnic_mat", new BlockPicnicMat());
    public static class_2248 GOMOKU = registerBlock("gomoku", new BlockGomoku());
    public static class_2248 CCHESS = registerBlock("cchess", new BlockCChess());
    public static class_2248 WCHESS = registerBlock("wchess", new BlockWChess());
    public static class_2248 KEYBOARD = registerBlock("keyboard", new BlockKeyboard());
    public static class_2248 BOOKSHELF = registerBlock("bookshelf", new BlockBookshelf());
    public static class_2248 COMPUTER = registerBlock("computer", new BlockComputer());
    public static class_2248 SHRINE = registerBlock("shrine", new BlockShrine());
    public static class_2248 SCARECROW = registerBlock("scarecrow", new BlockScarecrow());

    public static class_2591<TileEntityAltar> ALTAR_TE = registerBlockEntityType("altar", TileEntityAltar.TYPE);
    public static class_2591<TileEntityStatue> STATUE_TE = registerBlockEntityType("statue", TileEntityStatue.TYPE);
    public static class_2591<TileEntityGarageKit> GARAGE_KIT_TE = registerBlockEntityType("garage_kit", TileEntityGarageKit.TYPE);
    public static class_2591<TileEntityMaidBeacon> MAID_BEACON_TE = registerBlockEntityType("maid_beacon", TileEntityMaidBeacon.TYPE);
    public static class_2591<TileEntityModelSwitcher> MODEL_SWITCHER_TE = registerBlockEntityType("model_switcher", TileEntityModelSwitcher.TYPE);
    public static class_2591<TileEntityGomoku> GOMOKU_TE = registerBlockEntityType("gomoku", TileEntityGomoku.TYPE);
    public static class_2591<TileEntityCChess> CCHESS_TE = registerBlockEntityType("cchess", TileEntityCChess.TYPE);
    public static class_2591<TileEntityWChess> WCHESS_TE = registerBlockEntityType("wchess", TileEntityWChess.TYPE);
    public static class_2591<TileEntityKeyboard> KEYBOARD_TE = registerBlockEntityType("keyboard", TileEntityKeyboard.TYPE);
    public static class_2591<TileEntityBookshelf> BOOKSHELF_TE = registerBlockEntityType("bookshelf", TileEntityBookshelf.TYPE);
    public static class_2591<TileEntityComputer> COMPUTER_TE = registerBlockEntityType("computer", TileEntityComputer.TYPE);
    public static class_2591<TileEntityShrine> SHRINE_TE = registerBlockEntityType("shrine", TileEntityShrine.TYPE);
    public static class_2591<TileEntityPicnicMat> PICNIC_MAT_TE = registerBlockEntityType("picnic_mat", TileEntityPicnicMat.TYPE);
    public static class_2591<TileEntityMaidBed> MAID_BED_TE = registerBlockEntityType("maid_bed", TileEntityMaidBed.TYPE);

    private static class_2248 registerBlock(String id, class_2248 block) {
        return class_2378.method_10230(class_7923.field_41175, class_2960.method_60655(TouhouLittleMaid.MOD_ID, id), block);
    }

    private static <T extends class_2591<?>> T registerBlockEntityType(String id, T block) {
        return class_2378.method_10230(class_7923.field_41181, class_2960.method_60655(TouhouLittleMaid.MOD_ID, id), block);
    }
}
